# Properties

## _Property
::: pyflp._properties._Property

## _BoolProperty
::: pyflp._properties._BoolProperty

## _BytesProperty
::: pyflp._properties._BytesProperty

## _ColorProperty
::: pyflp._properties._ColorProperty

## _EnumProperty
::: pyflp._properties._EnumProperty

## _FloatProperty
::: pyflp._properties._FloatProperty

## _IntProperty
::: pyflp._properties._IntProperty

## _StrProperty
::: pyflp._properties._StrProperty

## _UIntProperty
::: pyflp._properties._UIntProperty
